from setuptools import setup

setup(
    name='pitches',
    version='0.1.0',    
    description='Convert between scientific pitch notation and frequency',
    url='https://github.com/kapteynpeter/pitches',
    author='Peter Kapteyn',
    author_email='kapteynpeter@gmail.com',
    license='MIT',
    packages=['pitches'],

    classifiers=[
        'Programming Language :: Python :: 3.5',
    ],
)